Re: [PATCH 10/12] MINGW: config.mak.uname: drop USE_NED_ALLOCATOR
- From
Marat Radchenko <marat@slonopotamus.org>
- Date
- Apr 29, 2014, 07:48 UTC
- Message-ID
- <20140429074814.GA23421@seldon>
- In-Reply-To
- <CABPQNSZD5jz1A8=zQvU4dYvNb-5M+TV50Uj+oVbWJs3YWBytHw@mail.gmail.com>
On Mon, Apr 28, 2014 at 05:23:25PM +0200, Erik Faye-Lund wrote:
Show 11 quoted lines
> On Mon, Apr 28, 2014 at 3:51 PM, Marat Radchenko <marat@slonopotamus.org> wrote: > > nedalloc was initially added in f0ed82 to fix slowness of standard WinXP > > memory allocator. Since WinXP is EOLed, this point is no longer valid. > > > > The actual reason behind this commit is incompatibility of malloc.c.h > > with MinGW-W64 headers. Alternative solution implies updating nedalloc > > to something newer. > > Did you measure that malloc on newer Windows-versions are actually > faster? AFAIK, malloc does a lot more inside the CRT than in the > kernel...
Windows 8, msysGit.
git repack -adf on msysgit/git (best of 3 runs)
+ nedalloc: 10.5s - nedalloc: 11s
git repack -adf on torvalds/linux (best of 3 runs)
+ nedalloc: 3m 24s - nedalloc: 3m 47s
We need to make a decision: drop nedalloc, update nedalloc to later release, patch nedalloc to make it work under MinGW-W64 or disable nedalloc under MinGW-W64 (still leaving it enabled under MinGW).
P.S. Waiting for "Resolving deltas" when cloning torvalds/linux is a pain, perhaps someone should run gprof on it.